@@ -58,8 +58,8 @@ process management, such as L<AnyEvent::DBI>.
 
 The problems that all these modules try to solve are real, however, none
 of them (from what I have seen) tackle the very real problems of unwanted
-memory sharing, efficiency, not being able to use event processing or
-similar modules in the processes they create.
+memory sharing, efficiency or not being able to use event processing, GUI
+toolkits or similar modules in the processes they create.
 
 This module doesn't try to replace any of them - instead it tries to solve
 the problem of creating processes with a minimum of fuss and overhead (and
@@ -91,14 +91,25 @@ possible. This gives the speed of vfork, with the flexibility of fork.
 process.
 
 For example, modules or data files that are loaded will not use additional
-memory after a fork. When exec'ing a new process, modules and data files
-might need to be loaded again, at extra CPU and memory cost. But when
-forking, literally all data structures are copied - if the program frees
-them and replaces them by new data, the child processes will retain the
-old version even if it isn't used, which can suddenly and unexpectedly
-increase memory usage when freeing memory.
+memory after a fork. Exec'ing a new process, in contrast, means modules
+and data files might need to be loaded again, at extra CPU and memory
+cost.
 
-The trade-off is between more sharing with fork (which can be good or
+But when forking, you still create a copy of your data structures - if
+the program frees them and replaces them by new data, the child processes
+will retain the old version even if it isn't used, which can suddenly and
+unexpectedly increase memory usage when freeing memory.
+
+For example, L<Gtk2::CV> is an image viewer optimised for large
+directories (millions of pictures). It also forks subprocesses for
+thumbnail generation, which inherit the data structure that stores all
+file information. If the user changes the directory, it gets freed in
+the main process, leaving a copy in the thumbnailer processes. This can
+lead to many times the memory usage that would actually be required. The
+solution is to fork early (and being unable to dynamically generate more
+subprocesses or do this from a module)... or to use L<AnyEvent:Fork>.
+
+There is a trade-off between more sharing with fork (which can be good or
 bad), and no sharing with exec.
 
 This module allows the main program to do a controlled fork, and allows
@@ -113,7 +124,8 @@ shared and what isn't, at all times.
 =item Exec'ing a new perl process might be difficult.
 
 For example, it is not easy to find the correct path to the perl
-interpreter - C<$^X> might not be a perl interpreter at all.
+interpreter - C<$^X> might not be a perl interpreter at all. Worse, there
+might not even be a perl binary installed on the system.
 
 This module tries hard to identify the correct path to the perl
 interpreter. With a cooperative main program, exec'ing the interpreter
@@ -129,7 +141,8 @@ perl version, or parts of a distribution are newer than the ones already
 loaded.
 
 This module supports creating pre-initialised perl processes to be used as
-a template for new processes.
+a template for new processes at a later time, e.g. for use in a process
+pool.
 
 =item Forking might be impossible when a program is running.
 
@@ -137,8 +150,8 @@ For example, POSIX makes it almost impossible to fork from a
 multi-threaded program while doing anything useful in the child - in
 fact, if your perl program uses POSIX threads (even indirectly via
 e.g. L<IO::AIO> or L<threads>), you cannot call fork on the perl level
-anymore without risking corruption issues on a number of operating
-systems.
+anymore without risking memory corruption or worse on a number of
+operating systems.
 
 This module can safely fork helper processes at any time, by calling
 fork+exec in C, in a POSIX-compatible way (via L<Proc::FastSpawn>).
@@ -167,6 +180,8 @@ possible to use modules such as event loops or window interfaces safely.
 
 =head1 EXAMPLES
 
+This is where the wall of text ends and code speaks.
+
 =head2 Create a single new process, tell it to run your worker function.
 
    AnyEvent::Fork
@@ -187,7 +202,7 @@ C<MyModule> might look like this:
       my ($slave_filehandle) = @_;
 
       # now $slave_filehandle is connected to the $master_filehandle
-      # in the original prorcess. have fun!
+      # in the original process. have fun!
    }
 
 =head2 Create a pool of server processes all accepting on the same socket.
@@ -258,7 +273,7 @@ faster than fork+exec, but still lets you prepare the environment.
 
 =head2 For stingy users: put the worker code into a C<DATA> section.
 
-When you want to be stingy with files, you cna put your code into the
+When you want to be stingy with files, you can put your code into the
 C<DATA> section of your module (or program):
 
    use AnyEvent::Fork;
@@ -278,8 +293,8 @@ C<DATA> section of your module (or program):
 all.
 
 For single-file scripts it can be inconvenient to rely on external
-files - even when using < C<DATA> section, you still need to C<exec>
-an external perl interpreter, which might not be available when using
+files - even when using a C<DATA> section, you still need to C<exec> an
+external perl interpreter, which might not be available when using
 L<App::Staticperl>, L<Urlader> or L<PAR::Packer> for example.
 
 Two modules help here - L<AnyEvent::Fork::Early> forks a template process
@@ -306,7 +321,7 @@ Here is how your main program should look like:
    }
 
    # now preserve everything so far as AnyEvent::Fork object
-   # in §TEMPLATE.
+   # in $TEMPLATE.
    use AnyEvent::Fork::Template;
 
    # do not put code outside of BEGIN blocks until here
@@ -452,7 +467,7 @@ use AnyEvent::Util ();
 
 use IO::FDPass;
 
-our $VERSION = 1.2;
+our $VERSION = 1.3;
 
 # the early fork template process
 our $EARLY;
@@ -627,7 +642,7 @@ sub new_exec {
 
    unless (defined $PERL) {
       # first find path of perl
-      my $perl = $;
+      my $perl = $^X;
 
       # first we try $^X, but the path must be absolute (always on win32), and end in sth.
       # that looks like perl. this obviously only works for posix and win32
@@ -660,7 +675,7 @@ sub new_exec {
 
    my $pid = Proc::FastSpawn::spawn (
       $PERL,
-      ["perl", "-MAnyEvent::Fork::Serve", "-e", "AnyEvent::Fork::Serve::me", fileno $slave, $$],
+      [$PERL, "-MAnyEvent::Fork::Serve", "-e", "AnyEvent::Fork::Serve::me", fileno $slave, $$],
       [map "$_=$env{$_}", keys %env],
    ) or die "unable to spawn AnyEvent::Fork server: $!";
 
@@ -707,6 +722,12 @@ a faster fork+exec> example to see it in action.
 
 Returns the process object for easy chaining of method calls.
 
+It's common to want to call an iniitalisation function with some
+arguments. Make sure you actually pass C<@_> to that function (for example
+by using C<&name> syntax), and do not just specify a function name:
+
+   $proc->eval ('&MyModule::init', $string1, $string2);
+
 =cut
 
 sub eval {
@@ -1082,6 +1103,23 @@ shortcomings of its API - see L<IO::FDPoll> for more details. If you never
 use C<send_fh> and always use C<new_exec> to create processes, it should
 work though.
 
+=head1 USING AnyEvent::Fork IN SUBPROCESSES
+
+AnyEvent::Fork itself cannot generally be used in subprocesses. As long as
+only one process ever forks new processes, sharing the template processes
+is possible (you could use a pipe as a lock by writing a byte into it to
+unlock, and reading the byte to lock for example)
+
+To make concurrent calls possible after fork, you should get rid of the
+template and early fork processes. AnyEvent::Fork will create a new
+template process as needed.
+
+   undef $AnyEvent::Fork::EARLY;
+   undef $AnyEvent::Fork::TEMPLATE;
+
+It doesn't matter whether you get rid of them in the parent or child after
+a fork.
+
 =head1 SEE ALSO
 
 L<AnyEvent::Fork::Early>, to avoid executing a perl interpreter at all
